# coding: utf-8

"""
    PAY.JP API v2

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 2.0.0
    Contact: support@pay.jp
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from payjpv2.models.checkout_session_mode import CheckoutSessionMode
from payjpv2.models.checkout_session_payment_method_options_request import CheckoutSessionPaymentMethodOptionsRequest
from payjpv2.models.checkout_session_submit_type import CheckoutSessionSubmitType
from payjpv2.models.checkout_session_ui_mode import CheckoutSessionUIMode
from payjpv2.models.currency import Currency
from payjpv2.models.customer_creation import CustomerCreation
from payjpv2.models.line_item_request import LineItemRequest
from payjpv2.models.locale import Locale
from payjpv2.models.metadata_value import MetadataValue
from payjpv2.models.payment_flow_data_request import PaymentFlowDataRequest
from payjpv2.models.payment_method_types import PaymentMethodTypes
from payjpv2.models.setup_flow_data_request import SetupFlowDataRequest
from typing import Optional, Set
from typing_extensions import Self

class CheckoutSessionCreateRequest(BaseModel):
    """
    CheckoutSessionCreateRequest
    """ # noqa: E501
    mode: CheckoutSessionMode = Field(description="Checkout Session のモード  | 指定できる値 | |:---| | **payment**: 支払いモードで Checkout Session を作成します。 | | **setup**: セットアップモードで Checkout Session を作成します。 |")
    client_reference_id: Optional[StrictStr] = Field(default=None, description="ID")
    customer_id: Optional[StrictStr] = Field(default=None, description="顧客 ID")
    customer_email: Optional[StrictStr] = Field(default=None, description="顧客オブジェクトを作成する時に使われます。指定されていない場合、顧客にメールアドレスの入力を求めます。すでに顧客のメールアドレスを持っている場合は、このパラメータを使ってあらかじめ情報を入力しておくことが可能です。")
    customer_creation: Optional[CustomerCreation] = Field(default=None, description="Checkout Session の確定時に Customer を作成するかどうかを指定します。<br> `payment` および `setup` モードでのみ設定可能です。")
    line_items: Optional[Annotated[List[LineItemRequest], Field(max_length=100)]] = Field(default=None, description="顧客が購入する商品のリストです。このパラメーターを使用して、1回限りまたは定期的な料金を渡します。  `payment` モードの場合、最大100個のラインアイテムを使用できます。")
    metadata: Optional[Dict[str, MetadataValue]] = Field(default=None, description="キーバリューの任意のデータを格納できます。20件まで登録可能で、空文字列を指定するとそのキーを削除できます。<a href=\"https://docs.pay.jp/v2/guide/developers/metadata\">詳細はメタデータのドキュメントを参照してください。</a>")
    success_url: Optional[StrictStr] = Field(default=None, description="支払いや設定が完了した際に、PAY.JP が顧客をリダイレクトする URL。成功した Checkout Session からの情報をページで使用したい場合は、成功ページのカスタマイズに関するガイドをお読みください。")
    cancel_url: Optional[StrictStr] = Field(default=None, description="キャンセル時のリダイレクト URL")
    currency: Optional[Currency] = Field(default=None, description="価格の通貨。現在は `jpy` のみサポートしています。")
    expires_at: Optional[datetime] = Field(default=None, description="Checkout Session の有効期限が失効する日時")
    locale: Optional[Locale] = Field(default=None, description="Checkout 画面の表示言語を指定します。  | 指定できる値 | |:---| | **ja**: 日本語で表示します。 |")
    payment_method_types: Optional[List[PaymentMethodTypes]] = Field(default=None, description="この PaymentFlow で使用できる支払い方法の種類（カードなど）のリストです。指定しない場合、管理画面で利用可能な状態にしている支払い方法を自動的に表示します。")
    payment_method_options: Optional[CheckoutSessionPaymentMethodOptionsRequest] = Field(default=None, description="この PaymentFlow の支払い方法の個別設定")
    payment_flow_data: Optional[PaymentFlowDataRequest] = Field(default=None, description="`payment` モード指定時に PaymentFlow 作成に使用するパラメーター")
    submit_type: Optional[CheckoutSessionSubmitType] = Field(default=None, description="Checkout の画面上に表示される送信ボタンなど、ページ上の関連テキストをカスタマイズするために使用されます。<br> `submit_type` は、`payment` モードの Checkout Session でのみ指定できます。未指定時、あるいは `auto` の場合、`pay` が使用されます。  | 指定できる値 | |:---| | **auto**: `pay` が使用されます。 | | **pay**: 「支払う」（デフォルト） | | **book**: 「予約する」 | | **donate**: 「寄付する」 |")
    setup_flow_data: Optional[SetupFlowDataRequest] = Field(default=None, description="`setup` モードの Checkout Session を作成する際、SetupFlow の作成に渡されるパラメーター")
    ui_mode: Optional[CheckoutSessionUIMode] = Field(default=None, description="Checkout Session の UI モード。デフォルトは `hosted` です。  | 指定できる値 | |:---| | **hosted**: PAY.JP でホスティングしている画面を使用します。 |")
    __properties: ClassVar[List[str]] = ["mode", "client_reference_id", "customer_id", "customer_email", "customer_creation", "line_items", "metadata", "success_url", "cancel_url", "currency", "expires_at", "locale", "payment_method_types", "payment_method_options", "payment_flow_data", "submit_type", "setup_flow_data", "ui_mode"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.model_dump(by_alias=True, exclude_unset=True))

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CheckoutSessionCreateRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in line_items (list)
        _items = []
        if self.line_items:
            for _item_line_items in self.line_items:
                if _item_line_items:
                    _items.append(_item_line_items.to_dict())
            _dict['line_items'] = _items
        # override the default output from pydantic by calling `to_dict()` of each value in metadata (dict)
        _field_dict = {}
        if self.metadata:
            for _key_metadata in self.metadata:
                if self.metadata[_key_metadata]:
                    _field_dict[_key_metadata] = self.metadata[_key_metadata].to_dict()
            _dict['metadata'] = _field_dict
        # override the default output from pydantic by calling `to_dict()` of payment_method_options
        if self.payment_method_options:
            _dict['payment_method_options'] = self.payment_method_options.to_dict()
        # override the default output from pydantic by calling `to_dict()` of payment_flow_data
        if self.payment_flow_data:
            _dict['payment_flow_data'] = self.payment_flow_data.to_dict()
        # override the default output from pydantic by calling `to_dict()` of setup_flow_data
        if self.setup_flow_data:
            _dict['setup_flow_data'] = self.setup_flow_data.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CheckoutSessionCreateRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "mode": obj.get("mode"),
            "client_reference_id": obj.get("client_reference_id"),
            "customer_id": obj.get("customer_id"),
            "customer_email": obj.get("customer_email"),
            "customer_creation": obj.get("customer_creation"),
            "line_items": [LineItemRequest.from_dict(_item) for _item in obj["line_items"]] if obj.get("line_items") is not None else None,
            "metadata": dict(
                (_k, MetadataValue.from_dict(_v))
                for _k, _v in obj["metadata"].items()
            )
            if obj.get("metadata") is not None
            else None,
            "success_url": obj.get("success_url"),
            "cancel_url": obj.get("cancel_url"),
            "currency": obj.get("currency"),
            "expires_at": obj.get("expires_at"),
            "locale": obj.get("locale"),
            "payment_method_types": obj.get("payment_method_types"),
            "payment_method_options": CheckoutSessionPaymentMethodOptionsRequest.from_dict(obj["payment_method_options"]) if obj.get("payment_method_options") is not None else None,
            "payment_flow_data": PaymentFlowDataRequest.from_dict(obj["payment_flow_data"]) if obj.get("payment_flow_data") is not None else None,
            "submit_type": obj.get("submit_type"),
            "setup_flow_data": SetupFlowDataRequest.from_dict(obj["setup_flow_data"]) if obj.get("setup_flow_data") is not None else None,
            "ui_mode": obj.get("ui_mode")
        })
        return _obj





# coding: utf-8

"""
    PAY.JP API v2

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 2.0.0
    Contact: support@pay.jp
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from payjpv2.models.payment_transaction_response import PaymentTransactionResponse

class TestPaymentTransactionResponse(unittest.TestCase):
    """PaymentTransactionResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PaymentTransactionResponse:
        """Test PaymentTransactionResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PaymentTransactionResponse`
        """
        model = PaymentTransactionResponse()
        if include_optional:
            return PaymentTransactionResponse(
                object = 'payment_transaction',
                id = '',
                livemode = True,
                resource_id = '',
                amount = 56,
                currency = 'jpy',
                fee_rate = ERROR_TO_EXAMPLE_VALUE,
                fee = 56,
                type = 'payment',
                payment_method_type = 'card',
                term_id = '',
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f')
            )
        else:
            return PaymentTransactionResponse(
                id = '',
                livemode = True,
                resource_id = '',
                amount = 56,
                currency = 'jpy',
                fee_rate = ERROR_TO_EXAMPLE_VALUE,
                fee = 56,
                type = 'payment',
                payment_method_type = 'card',
                term_id = '',
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
        )
        """

    def testPaymentTransactionResponse(self):
        """Test PaymentTransactionResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    PAY.JP API v2

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 2.0.0
    Contact: support@pay.jp
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from payjpv2.models.capture_method import CaptureMethod
from payjpv2.models.currency import Currency
from payjpv2.models.metadata_value import MetadataValue
from payjpv2.models.payment_flow_payment_method_options_request import PaymentFlowPaymentMethodOptionsRequest
from payjpv2.models.payment_method_types import PaymentMethodTypes
from typing import Optional, Set
from typing_extensions import Self

class PaymentFlowCreateRequest(BaseModel):
    """
    PaymentFlowCreateRequest
    """ # noqa: E501
    amount: Annotated[int, Field(le=9999999, strict=True, ge=50)] = Field(description="支払い予定の金額。50円以上9,999,999円以下である必要があります。")
    customer_id: Optional[StrictStr] = Field(default=None, description="この PaymentFlow に関連付ける顧客の ID")
    payment_method_id: Optional[StrictStr] = Field(default=None, description="支払い方法 ID。customer_id の指定が必須です。Customer が所持する PaymentMethod のみ指定できます。payment_method_id を指定せず、Customer に default_payment_method_id が設定されている場合はそちらが自動でセットされます。")
    payment_method_options: Optional[PaymentFlowPaymentMethodOptionsRequest] = Field(default=None, description="この PaymentFlow 固有の支払い方法の設定")
    payment_method_types: Optional[List[PaymentMethodTypes]] = Field(default=None, description="この PaymentFlow で使用できる支払い方法の種類のリスト。指定しない場合は、PAY.JP は支払い方法の設定から利用可能な支払い方法を動的に表示します。")
    currency: Currency = Field(description="価格の通貨。現在は `jpy` のみサポートしています。")
    capture_method: Optional[CaptureMethod] = Field(default=None, description="支払いの確定方法を指定します。  | 値 | |:---| | **automatic**: (デフォルト) 顧客が支払いを承認すると、自動的に確定させます。 | | **manual**: 顧客が支払いを承認すると一旦確定を保留し、後で Payment Flow の Capture API を使用して確定します。（すべての支払い方法がこれをサポートしているわけではありません）。 |")
    confirm: Optional[StrictBool] = Field(default=False, description="「true」に設定すると、この PaymentFlow を直ちに確定しようと試みます。")
    return_url: Optional[StrictStr] = Field(default=None, description="顧客が支払いを完了後かキャンセルした後にリダイレクトされる URL。アプリにリダイレクトしたい場合は URI Scheme を指定できます。confirm=true の場合のみ指定できます。")
    description: Optional[StrictStr] = Field(default=None, description="オブジェクトにセットする任意の文字列。")
    metadata: Optional[Dict[str, MetadataValue]] = Field(default=None, description="キーバリューの任意のデータを格納できます。20件まで登録可能で、空文字列を指定するとそのキーを削除できます。<a href=\"https://docs.pay.jp/v2/guide/developers/metadata\">詳細はメタデータのドキュメントを参照してください。</a>")
    __properties: ClassVar[List[str]] = ["amount", "customer_id", "payment_method_id", "payment_method_options", "payment_method_types", "currency", "capture_method", "confirm", "return_url", "description", "metadata"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.model_dump(by_alias=True, exclude_unset=True))

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of PaymentFlowCreateRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of payment_method_options
        if self.payment_method_options:
            _dict['payment_method_options'] = self.payment_method_options.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each value in metadata (dict)
        _field_dict = {}
        if self.metadata:
            for _key_metadata in self.metadata:
                if self.metadata[_key_metadata]:
                    _field_dict[_key_metadata] = self.metadata[_key_metadata].to_dict()
            _dict['metadata'] = _field_dict
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of PaymentFlowCreateRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "amount": obj.get("amount"),
            "customer_id": obj.get("customer_id"),
            "payment_method_id": obj.get("payment_method_id"),
            "payment_method_options": PaymentFlowPaymentMethodOptionsRequest.from_dict(obj["payment_method_options"]) if obj.get("payment_method_options") is not None else None,
            "payment_method_types": obj.get("payment_method_types"),
            "currency": obj.get("currency"),
            "capture_method": obj.get("capture_method"),
            "confirm": obj.get("confirm") if obj.get("confirm") is not None else False,
            "return_url": obj.get("return_url"),
            "description": obj.get("description"),
            "metadata": dict(
                (_k, MetadataValue.from_dict(_v))
                for _k, _v in obj["metadata"].items()
            )
            if obj.get("metadata") is not None
            else None
        })
        return _obj





"""
Tests for PAY.JP SDK configuration and client initialization.
"""
import os
import pytest
from unittest.mock import patch
import payjpv2
from payjpv2.configuration import Configuration
from payjpv2.api_client import ApiClient


class TestConfiguration:
    """Test SDK configuration."""

    def test_default_configuration(self):
        """Test default configuration values."""
        config = Configuration()
        
        # Test default values
        assert config.host is not None
        assert isinstance(config.api_key, dict)
        assert isinstance(config.api_key_prefix, dict)

    def test_configuration_with_api_key(self, api_key):
        """Test configuration with API key."""
        config = Configuration(
            host="https://api.pay.jp",
            api_key={'APIKeyHeader': api_key},
            api_key_prefix={'APIKeyHeader': 'Bearer'}
        )
        
        assert config.host == "https://api.pay.jp"
        assert config.api_key['APIKeyHeader'] == api_key
        assert config.api_key_prefix['APIKeyHeader'] == 'Bearer'

    def test_configuration_host_validation(self):
        """Test host validation."""
        # Valid hosts
        valid_hosts = [
            "https://api.pay.jp",
            "https://api.pay.jp/",
            "http://localhost:3000",
            "https://sandbox.api.pay.jp"
        ]
        
        for host in valid_hosts:
            config = Configuration(host=host)
            assert config.host is not None

    def test_api_key_configuration(self, api_key):
        """Test API key configuration options."""
        # Test with Bearer prefix
        config = Configuration(
            api_key={'APIKeyHeader': api_key},
            api_key_prefix={'APIKeyHeader': 'Bearer'}
        )
        assert config.api_key['APIKeyHeader'] == api_key
        assert config.api_key_prefix['APIKeyHeader'] == 'Bearer'
        
        # Test without prefix
        config_no_prefix = Configuration(
            api_key={'APIKeyHeader': api_key}
        )
        assert config_no_prefix.api_key['APIKeyHeader'] == api_key

    def test_configuration_from_environment(self):
        """Test configuration from environment variables."""
        with patch.dict(os.environ, {
            'PAYJP_API_KEY': 'sk_test_env_key',
            'PAYJP_HOST': 'https://api.pay.jp'
        }):
            # Test environment variable usage
            api_key = os.environ.get('PAYJP_API_KEY')
            host = os.environ.get('PAYJP_HOST')
            
            config = Configuration(
                host=host,
                api_key={'APIKeyHeader': api_key},
                api_key_prefix={'APIKeyHeader': 'Bearer'}
            )
            
            assert config.api_key['APIKeyHeader'] == 'sk_test_env_key'
            assert config.host == 'https://api.pay.jp'

    def test_configuration_validation(self):
        """Test configuration validation."""
        # Test empty API key
        config = Configuration(api_key={'APIKeyHeader': ''})
        assert config.api_key['APIKeyHeader'] == ''
        
        # Test None API key
        config = Configuration(api_key={'APIKeyHeader': None})
        assert config.api_key['APIKeyHeader'] is None

    def test_configuration_copy(self, configuration):
        """Test configuration copying."""
        # Create a copy
        config_copy = Configuration()
        config_copy.host = configuration.host
        config_copy.api_key = configuration.api_key.copy()
        config_copy.api_key_prefix = configuration.api_key_prefix.copy()
        
        # Verify copy is correct
        assert config_copy.host == configuration.host
        assert config_copy.api_key == configuration.api_key
        assert config_copy.api_key_prefix == configuration.api_key_prefix
        
        # Verify it's a deep copy
        config_copy.api_key['APIKeyHeader'] = 'different_key'
        assert config_copy.api_key['APIKeyHeader'] != configuration.api_key['APIKeyHeader']


class TestApiClient:
    """Test API client initialization and behavior."""

    def test_api_client_initialization(self, configuration):
        """Test API client initialization."""
        client = ApiClient(configuration)
        assert client.configuration == configuration
        assert client.configuration.host == configuration.host

    def test_api_client_context_manager(self, configuration):
        """Test API client as context manager."""
        with ApiClient(configuration) as client:
            assert client is not None
            assert client.configuration == configuration

    def test_api_client_with_custom_config(self, api_key):
        """Test API client with custom configuration."""
        custom_config = Configuration(
            host="https://custom.api.endpoint",
            api_key={'APIKeyHeader': api_key},
            api_key_prefix={'APIKeyHeader': 'Bearer'}
        )
        
        with ApiClient(custom_config) as client:
            assert client.configuration.host == "https://custom.api.endpoint"
            assert client.configuration.api_key['APIKeyHeader'] == api_key

    def test_multiple_clients_independence(self, api_key):
        """Test that multiple clients are independent."""
        config1 = Configuration(
            host="https://api1.pay.jp",
            api_key={'APIKeyHeader': api_key + "_1"}
        )
        config2 = Configuration(
            host="https://api2.pay.jp",
            api_key={'APIKeyHeader': api_key + "_2"}
        )
        
        client1 = ApiClient(config1)
        client2 = ApiClient(config2)
        
        assert client1.configuration.host != client2.configuration.host
        assert client1.configuration.api_key['APIKeyHeader'] != client2.configuration.api_key['APIKeyHeader']

    def test_api_client_default_headers(self, api_client):
        """Test API client default headers."""
        # Verify client has proper configuration
        assert api_client.configuration is not None
        
        # Test that User-Agent and other headers would be set
        # (This depends on the actual implementation)
        assert hasattr(api_client, 'configuration')

    def test_api_client_timeout_configuration(self):
        """Test API client timeout configuration."""
        config = Configuration()
        
        # Test default timeout (if applicable)
        with ApiClient(config) as client:
            assert client.configuration is not None
            # Add specific timeout tests based on actual implementation

    def test_configuration_thread_safety(self, configuration):
        """Test configuration thread safety."""
        import threading
        import time
        
        results = []
        
        def create_client():
            with ApiClient(configuration) as client:
                results.append(client.configuration.api_key['APIKeyHeader'])
                time.sleep(0.01)  # Small delay to test concurrency
        
        threads = []
        for _ in range(5):
            thread = threading.Thread(target=create_client)
            threads.append(thread)
            thread.start()
        
        for thread in threads:
            thread.join()
        
        # All results should be the same
        assert len(set(results)) == 1
        assert results[0] == configuration.api_key['APIKeyHeader']


# coding: utf-8

"""
    PAY.JP API v2

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 2.0.0
    Contact: support@pay.jp
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class ErrorResponse(BaseModel):
    """
    ErrorResponse
    """ # noqa: E501
    type: StrictStr
    title: StrictStr
    status: StrictInt
    detail: Optional[StrictStr] = None
    instance: Optional[StrictStr] = None
    errors: Optional[List[Dict[str, StrictStr]]] = None
    __properties: ClassVar[List[str]] = ["type", "title", "status", "detail", "instance", "errors"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.model_dump(by_alias=True, exclude_unset=True))

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ErrorResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if detail (nullable) is None
        # and model_fields_set contains the field
        if self.detail is None and "detail" in self.model_fields_set:
            _dict['detail'] = None

        # set to None if instance (nullable) is None
        # and model_fields_set contains the field
        if self.instance is None and "instance" in self.model_fields_set:
            _dict['instance'] = None

        # set to None if errors (nullable) is None
        # and model_fields_set contains the field
        if self.errors is None and "errors" in self.model_fields_set:
            _dict['errors'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ErrorResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "type": obj.get("type"),
            "title": obj.get("title"),
            "status": obj.get("status"),
            "detail": obj.get("detail"),
            "instance": obj.get("instance"),
            "errors": obj.get("errors")
        })
        return _obj





# coding: utf-8

"""
    PAY.JP API v2

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 2.0.0
    Contact: support@pay.jp
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from payjpv2.models.setup_flow_create_request import SetupFlowCreateRequest

class TestSetupFlowCreateRequest(unittest.TestCase):
    """SetupFlowCreateRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SetupFlowCreateRequest:
        """Test SetupFlowCreateRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SetupFlowCreateRequest`
        """
        model = SetupFlowCreateRequest()
        if include_optional:
            return SetupFlowCreateRequest(
                customer_id = '',
                payment_method_options = payjpv2.models.setup_flow_payment_method_options_request.SetupFlowPaymentMethodOptionsRequest(
                    card = payjpv2.models.setup_flow_payment_method_options_card_request.SetupFlowPaymentMethodOptionsCardRequest(
                        request_three_d_secure = 'automatic', ), ),
                payment_method_types = [
                    'card'
                    ],
                usage = 'on_session',
                description = '',
                metadata = {
                    'key' : null
                    }
            )
        else:
            return SetupFlowCreateRequest(
        )
        """

    def testSetupFlowCreateRequest(self):
        """Test SetupFlowCreateRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    PAY.JP API v2

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 2.0.0
    Contact: support@pay.jp
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from payjpv2.api.products_api import ProductsApi


class TestProductsApi(unittest.TestCase):
    """ProductsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ProductsApi()

    def tearDown(self) -> None:
        pass

    def test_create_product(self) -> None:
        """Test case for create_product

        Create Product
        """
        pass

    def test_delete_product(self) -> None:
        """Test case for delete_product

        Delete Product
        """
        pass

    def test_get_all_products(self) -> None:
        """Test case for get_all_products

        Get All Products
        """
        pass

    def test_get_product(self) -> None:
        """Test case for get_product

        Get Product
        """
        pass

    def test_update_product(self) -> None:
        """Test case for update_product

        Update Product
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    PAY.JP API v2

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 2.0.0
    Contact: support@pay.jp
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from payjpv2.models.term_response import TermResponse
from typing import Optional, Set
from typing_extensions import Self

class TermListResponse(BaseModel):
    """
    TermListResponse
    """ # noqa: E501
    object: Optional[StrictStr] = 'list'
    url: StrictStr = Field(description="リスト取得URL")
    has_more: StrictBool = Field(description="次のページがあるかどうか")
    data: List[TermResponse]
    __properties: ClassVar[List[str]] = ["object", "url", "has_more", "data"]

    @field_validator('object')
    def object_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['list']):
            raise ValueError("must be one of enum values ('list')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.model_dump(by_alias=True, exclude_unset=True))

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of TermListResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in data (list)
        _items = []
        if self.data:
            for _item_data in self.data:
                if _item_data:
                    _items.append(_item_data.to_dict())
            _dict['data'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of TermListResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "object": obj.get("object") if obj.get("object") is not None else 'list',
            "url": obj.get("url"),
            "has_more": obj.get("has_more"),
            "data": [TermResponse.from_dict(_item) for _item in obj["data"]] if obj.get("data") is not None else None
        })
        return _obj





# coding: utf-8

"""
    PAY.JP API v2

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 2.0.0
    Contact: support@pay.jp
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from payjpv2.models.payment_method_card_details_response import PaymentMethodCardDetailsResponse

class TestPaymentMethodCardDetailsResponse(unittest.TestCase):
    """PaymentMethodCardDetailsResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PaymentMethodCardDetailsResponse:
        """Test PaymentMethodCardDetailsResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PaymentMethodCardDetailsResponse`
        """
        model = PaymentMethodCardDetailsResponse()
        if include_optional:
            return PaymentMethodCardDetailsResponse(
                last4 = '',
                brand = '',
                exp_month = 56,
                exp_year = 56,
                fingerprint = '',
                country = ''
            )
        else:
            return PaymentMethodCardDetailsResponse(
                last4 = '',
                brand = '',
                exp_month = 56,
                exp_year = 56,
                fingerprint = '',
                country = '',
        )
        """

    def testPaymentMethodCardDetailsResponse(self):
        """Test PaymentMethodCardDetailsResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    PAY.JP API v2

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 2.0.0
    Contact: support@pay.jp
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from payjpv2.models.checkout_session_list_response import CheckoutSessionListResponse

class TestCheckoutSessionListResponse(unittest.TestCase):
    """CheckoutSessionListResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CheckoutSessionListResponse:
        """Test CheckoutSessionListResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CheckoutSessionListResponse`
        """
        model = CheckoutSessionListResponse()
        if include_optional:
            return CheckoutSessionListResponse(
                object = 'list',
                url = '',
                has_more = True,
                data = [
                    payjpv2.models.checkout_session_details_response.CheckoutSessionDetailsResponse(
                        object = 'checkout.session', 
                        id = '', 
                        livemode = True, 
                        amount_subtotal = 56, 
                        amount_total = 56, 
                        customer_id = '', 
                        customer_email = '', 
                        customer_details = payjpv2.models.checkout_session_customer_details_response.CheckoutSessionCustomerDetailsResponse(
                            name = '', 
                            email = '', 
                            phone = '', 
                            address = payjpv2.models.checkout_session_customer_details_address_response.CheckoutSessionCustomerDetailsAddressResponse(
                                country = '', 
                                zip = '', 
                                state = '', 
                                city = '', 
                                line1 = '', 
                                line2 = '', ), ), 
                        expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        currency = 'jpy', 
                        locale = 'auto', 
                        payment_flow_id = '', 
                        payment_method_types = [
                            'card'
                            ], 
                        payment_method_options = { }, 
                        setup_flow_id = '', 
                        submit_type = 'auto', 
                        mode = 'payment', 
                        ui_mode = 'hosted', 
                        status = 'open', 
                        success_url = '', 
                        cancel_url = '', 
                        url = '', 
                        metadata = {
                            'key' : null
                            }, 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ]
            )
        else:
            return CheckoutSessionListResponse(
                url = '',
                has_more = True,
                data = [
                    payjpv2.models.checkout_session_details_response.CheckoutSessionDetailsResponse(
                        object = 'checkout.session', 
                        id = '', 
                        livemode = True, 
                        amount_subtotal = 56, 
                        amount_total = 56, 
                        customer_id = '', 
                        customer_email = '', 
                        customer_details = payjpv2.models.checkout_session_customer_details_response.CheckoutSessionCustomerDetailsResponse(
                            name = '', 
                            email = '', 
                            phone = '', 
                            address = payjpv2.models.checkout_session_customer_details_address_response.CheckoutSessionCustomerDetailsAddressResponse(
                                country = '', 
                                zip = '', 
                                state = '', 
                                city = '', 
                                line1 = '', 
                                line2 = '', ), ), 
                        expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        currency = 'jpy', 
                        locale = 'auto', 
                        payment_flow_id = '', 
                        payment_method_types = [
                            'card'
                            ], 
                        payment_method_options = { }, 
                        setup_flow_id = '', 
                        submit_type = 'auto', 
                        mode = 'payment', 
                        ui_mode = 'hosted', 
                        status = 'open', 
                        success_url = '', 
                        cancel_url = '', 
                        url = '', 
                        metadata = {
                            'key' : null
                            }, 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ],
        )
        """

    def testCheckoutSessionListResponse(self):
        """Test CheckoutSessionListResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
